<?php

namespace Litematrimony\Preference\Providers;

use Illuminate\Support\ServiceProvider;

class PreferenceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'preference');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'preference');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litematrimony.preference', function ($app) {
            return $this->app->make('Litematrimony\Preference\Preference');
        });

                // Bind Preference to repository
        $this->app->bind(
            'Litematrimony\Preference\Interfaces\PreferenceRepositoryInterface',
            \Litematrimony\Preference\Repositories\Eloquent\PreferenceRepository::class
        );

        $this->app->register(\Litematrimony\Preference\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litematrimony\Preference\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litematrimony.preference'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litematrimony/preference.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/preference')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/preference')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
